@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: arp.tcl,v 1.17 1999/01/18 21:37:40 jfontain Exp $}
+set rcsId {$Id: arp.tcl,v 1.18 1999/02/26 20:51:04 jfontain Exp $}
 
 
-package provide arp 1.4
+package provide arp 1.5
 package require network 1.2
 
 namespace eval arp {
@@ -36,12 +36,17 @@ namespace eval arp {
         if {![catch {set locator $options(--remote)}]||![catch {set locator $options(-r)}]} {                   ;# remote monitoring
             set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
             foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
-            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /proc/net/arp; echo $?}]!=0} {
-                puts stderr "on remote host $remote(host) as user $remote(user), /proc/net/arp is not readable"
+            set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/arp"]
+            fileevent $file readable {set ::arp::remote(busy) 0}
+            vwait ::arp::remote(busy)                                                                       ;# allow GUI interaction
+            if {[catch {close $file} message]} {
+                puts stderr "on remote host $remote(host) as user $remote(user): $message"
                 exit 1                                                                                        ;# detect errors early
             }
-            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /etc/ethers; echo $?}]==0} {
-                # check file readability because opening always works
+            set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /etc/ethers"]
+            fileevent $file readable {set ::arp::remote(busy) 0}
+            vwait ::arp::remote(busy)                                                                       ;# allow GUI interaction
+            if {![catch {close $file}]} {                                     ;# check file readability because opening always works
                 set ethernetFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /etc/ethers"]
             }
         } else {
@@ -91,7 +96,14 @@ namespace eval arp {
         variable lookup
 
         if {[info exists remote]} {
-            set arpFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/arp"]
+            if {![info exists arpFile]} {                                  ;# start data gathering process in a non blocking fashion
+                if {$remote(busy)} return                                           ;# core invocation while waiting for remote data
+                set remote(busy) 1
+                set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/arp"]
+                fileevent $file readable "set ::arp::arpFile $file; ::arp::update"   ;# do not hang GUI, allow other modules updates
+                return                                                                                       ;# wait for remote data
+            }                                                                                 ;# else continue below to process data
+
         } else {
             seek $arpFile 0                                                                         ;# rewind before retrieving data
         }
@@ -129,15 +141,17 @@ namespace eval arp {
             set data($row,5) $interface
             set current($address) {}
         }
-        if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
-            close $arpFile
-        }
         foreach address [array names index] {                                                         ;# cleanup disappeared entries
             if {[info exists current($address)]} continue
             set row $index($address)
             unset index($address) data($row,0) data($row,1) data($row,2) data($row,3)
         }
         incr data(updates)
+        if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
+            close $arpFile
+            unset arpFile
+            set remote(busy) 0
+        }
     }
 
 }
