@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: canvhand.tcl,v 1.26 1999/01/29 21:52:31 jfontain Exp $}
+set rcsId {$Id: canvhand.tcl,v 1.27 1999/03/06 17:42:45 jfontain Exp $}
 
 class canvasWindowManager {
 
@@ -102,7 +102,7 @@ class canvasWindowManager {
         proc buttonPress {this x y} {
             set canvasWindowManager::handles::(xLast) $x                             ;### Tcl BUG: should be set ([xy]Last) $... ###
             set canvasWindowManager::handles::(yLast) $y
-            lifoLabel::push $::messenger {}          ;# in case no other string is pushed before button release event pops messenger
+            lifoLabel::push $global::messenger {}    ;# in case no other string is pushed before button release event pops messenger
             createOutline $this
         }
 
@@ -115,7 +115,7 @@ class canvasWindowManager {
         }
 
         proc buttonRelease {this} {
-            lifoLabel::pop $::messenger
+            lifoLabel::pop $global::messenger
             if {[info exists (motion)]} {                                                              ;# moving or resizing occured
                 updateGeometry $this
                 stack $this raise                                                   ;# always place widget on top after acting on it
@@ -211,7 +211,7 @@ class canvasWindowManager {
         }
 
         proc updateOutline {this x y} {                                                 ;# coordinates are relative to manager frame
-            lifoLabel::pop $::messenger                                                       ;# remove previous coordinates or size
+            lifoLabel::pop $global::messenger                                                 ;# remove previous coordinates or size
 
             if {[set (hidden)]} {                                                              ;# make sure outline is fully visible
                 stackOutline $this raise
@@ -238,7 +238,7 @@ class canvasWindowManager {
 
             if {[string length [set ($this,direction)]]==0} {                                                ;# moving, not resizing
                 $canvas move outline [expr {$x-[set (xLast)]}] [expr {$y-[set (yLast)]}]
-                lifoLabel::push $::messenger [$canvas coords outline]                     ;# display new coordinates in message area
+                lifoLabel::push $global::messenger [$canvas coords outline]               ;# display new coordinates in message area
                 set canvasWindowManager::handles::(xLast) $x                         ;### Tcl BUG: should be set ([xy]Last) $... ###
                 set canvasWindowManager::handles::(yLast) $y
                 return
@@ -297,7 +297,7 @@ class canvasWindowManager {
         }
 
         proc displayOutline {this x y width height} {                                          ;# coordinates are relative to canvas
-            lifoLabel::push $::messenger "$width x $height"                                      ;# display new size in message area
+            lifoLabel::push $global::messenger "$width x $height"                                ;# display new size in message area
             set minimum [expr {(2*$composite::($this,-borderwidth))+1}]                ;# make sure managed widget is always visible
             set width [maximum $minimum $width]
             set height [maximum $minimum $height]
