@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: databar.tcl,v 1.18 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: databar.tcl,v 1.19 1999/03/13 21:35:22 jfontain Exp $}
 
 class dataBarChart {
 
@@ -11,12 +11,8 @@ class dataBarChart {
             -plotbackground $widget::(default,ButtonBackgroundColor)\
         ] $args
     } blt2DViewer {$widget::($this,path)} {
-if {$::officialBLT} {
         $widget::($this,path) grid off                                                                      ;# grid is on by default
         $widget::($this,path) xaxis configure -hide 1
-} else {
-        $widget::($this,path) xaxis configure -mapped 0
-}
         composite::complete $this
     }
 
@@ -162,8 +158,6 @@ class dataStackedBarChart {
     }
 }
 
-if {$officialBLT} {
-
 class dataOverlapBarChart {
     proc dataOverlapBarChart {this parentPath args} dataBarChart {$parentPath $args} {
         composite::configure $this -mode overlap
@@ -188,5 +182,3 @@ class dataOverlapBarChart {
         }
     }
 }
-
-}
