@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datatab.tcl,v 1.55 1999/01/02 14:03:45 jfontain Exp $}
+set rcsId {$Id: datatab.tcl,v 1.56 1999/03/06 17:42:45 jfontain Exp $}
 
 class dataTable {                       ;# module data view in the form of a table, that can be sorted using a column as a reference
 
@@ -322,8 +322,8 @@ class dataTable {                       ;# module data view in the form of a tab
             $path window configure -1,$column -window $frame -padx 2 -pady 2 -sticky nsew
             bind $label <ButtonRelease-1> "dataTable::columnSort $this $dataColumn; dataTable::updateSortingArrow $this $column"
             # setup context sensitive help on titles using help strings from module data
-            bind $label <Enter> "lifoLabel::push $::messenger [list $data($dataColumn,message)]"
-            bind $label <Leave> "lifoLabel::pop $::messenger"
+            bind $label <Enter> "lifoLabel::push $global::messenger [list $data($dataColumn,message)]"
+            bind $label <Leave> "lifoLabel::pop $global::messenger"
             lappend dataTable::($this,tips) [new widgetTip -path $label -text {click to toggle sort}]
             incr column
         }
