@@ -1,21 +1,17 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: gui.tcl,v 1.3 1999/01/16 16:20:57 jfontain Exp $}
+set rcsId {$Id: gui.tcl,v 1.9 1999/03/13 21:35:22 jfontain Exp $}
 
 proc updateTitle {} {                                                          ;# show modules and poll time or mode in window title
-    global pollTimes pollTime modules
-
-    if {[llength $pollTimes]==0} {
+    if {[llength $global::pollTimes]==0} {
         wm title . "moodss: [commaSeparatedString $modules::(all)] data (asynchronous)"
     } else {
-        wm title . "moodss: [commaSeparatedString $modules::(all)] data (every $pollTime seconds)"
+        wm title . "moodss: [commaSeparatedString $modules::(all)] data (every $global::pollTime seconds)"
     }
 }
 
 proc createMenuWidget {parentPath readOnly includePollTime} {
-    global static
-
     set menu [menu $parentPath.menu -tearoff 0]
     $menu add cascade -label File -menu [menu $menu.file -tearoff 0] -underline 0
     if {!$readOnly} {
@@ -32,18 +28,18 @@ proc createMenuWidget {parentPath readOnly includePollTime} {
     }
     if {!$readOnly} {
         $menu add cascade -label New -menu [menu $menu.new -tearoff 0] -underline 0
-        $menu.new add command -label {Graph Chart...} -underline 0 -command "createCellsViewer dataGraph {} 1 $static \$pollTime"
-if {$::officialBLT} {
+        $menu.new add command -label {Graph Chart...} -underline 0\
+            -command "createCellsViewer dataGraph {} 1 $global::static \$global::pollTime"
         $menu.new add command -label {Overlap Bar Chart...} -underline 0\
-            -command "createCellsViewer dataOverlapBarChart {} 1 $static"
-}
-        $menu.new add command -label {Side Bar Chart...} -underline 5 -command "createCellsViewer dataSideBarChart {} 1 $static"
+            -command "createCellsViewer dataOverlapBarChart {} 1 $global::static"
+        $menu.new add command -label {Side Bar Chart...} -underline 5\
+            -command "createCellsViewer dataSideBarChart {} 1 $global::static"
         $menu.new add command -label {Stacked Bar Chart...} -underline 0\
-            -command "createCellsViewer dataStackedBarChart {} 1 $static"
-        $menu.new add command -label {2D Pie Chart...} -underline 0 -command "createCellsViewer data2DPieChart {} 1 $static"
-        $menu.new add command -label {3D Pie Chart...} -underline 0 -command "createCellsViewer data3DPieChart {} 1 $static"
-        $menu.new add command -label {Summary Table...} -underline 8 -command "createCellsViewer summaryTable {} 1 $static"
-        $menu.new add command -label {Free Text...} -underline 0 -command "createCellsViewer freeText {} 1 $static"
+            -command "createCellsViewer dataStackedBarChart {} 1 $global::static"
+        $menu.new add command -label {2D Pie Chart...} -underline 0 -command "createCellsViewer data2DPieChart {} 1 $global::static"
+        $menu.new add command -label {3D Pie Chart...} -underline 0 -command "createCellsViewer data3DPieChart {} 1 $global::static"
+        $menu.new add command -label {Summary Table...} -underline 8 -command "createCellsViewer summaryTable {} 1 $global::static"
+        $menu.new add command -label {Free Text...} -underline 0 -command "createCellsViewer freeText {} 1 $global::static"
     }
     $menu add cascade -label Help -menu [menu $menu.help -tearoff 0] -underline 0
     $menu.help add command -label Global... -underline 0 -accelerator F1 -command generalHelpWindow
@@ -60,10 +56,8 @@ if {$::officialBLT} {
 }
 
 proc createMessageWidget {parentPath} {
-    global messenger
-
-    set messenger [new lifoLabel $parentPath -headerfont $font::(mediumBold) -font $font::(mediumNormal)]
-    return $widget::($messenger,path)                                                                     ;# return actual tk widget
+    set global::messenger [new lifoLabel $parentPath -headerfont $font::(mediumBold) -font $font::(mediumNormal)]
+    return $widget::($global::messenger,path)                                                             ;# return actual tk widget
 }
 
 proc dragEcho {data format} {
@@ -71,31 +65,28 @@ proc dragEcho {data format} {
 }
 
 proc createDragAndDropZone {parentPath} {
-    global canvas pollTime static
-
     set frame [frame $parentPath.drops]
 
     set label [label $frame.graph -image applicationIcon]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
-        -command "createCellsViewer dataGraph \$dragSite::data(DATACELLS) 1 $static \$pollTime"
+        -command "createCellsViewer dataGraph \$dragSite::data(DATACELLS) 1 $global::static \$global::pollTime"
     new widgetTip -path $label -text "graph chart\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::dataGraph}
 
-if {$::officialBLT} {
     set label [label $frame.overlapBarChart -image [image create photo -data [dataOverlapBarChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
-        -command "createCellsViewer dataOverlapBarChart \$dragSite::data(DATACELLS) 1 $static"
+        -command "createCellsViewer dataOverlapBarChart \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "overlap bar chart\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::dataOverlapBarChart}
-}
 
     set label [label $frame.sideBarChart -image [image create photo -data [dataSideBarChart::iconData]]]
     pack $label -pady 1 -side left
-    new dropSite -path $label -formats DATACELLS -command "createCellsViewer dataSideBarChart \$dragSite::data(DATACELLS) 1 $static"
+    new dropSite -path $label -formats DATACELLS\
+        -command "createCellsViewer dataSideBarChart \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "side bar chart\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::dataSideBarChart}
@@ -103,35 +94,39 @@ if {$::officialBLT} {
     set label [label $frame.stackedBarChart -image [image create photo -data [dataStackedBarChart::iconData]]]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
-        -command "createCellsViewer dataStackedBarChart \$dragSite::data(DATACELLS) 1 $static"
+        -command "createCellsViewer dataStackedBarChart \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "stacked bar chart\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::dataStackedBarChart}
 
     set label [label $frame.2DPieChart -image [image create photo -data [data2DPieChart::iconData]]]
     pack $label -pady 1 -side left
-    new dropSite -path $label -formats DATACELLS -command "createCellsViewer data2DPieChart \$dragSite::data(DATACELLS) 1 $static"
+    new dropSite -path $label -formats DATACELLS\
+        -command "createCellsViewer data2DPieChart \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "2D pie chart\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::data2DPieChart}
 
     set label [label $frame.3DPieChart -image [image create photo -data [data3DPieChart::iconData]]]
     pack $label -pady 1 -side left
-    new dropSite -path $label -formats DATACELLS -command "createCellsViewer data3DPieChart \$dragSite::data(DATACELLS) 1 $static"
+    new dropSite -path $label -formats DATACELLS\
+        -command "createCellsViewer data3DPieChart \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "3D pie chart\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::data3DPieChart}
 
     set label [label $frame.summaryTable -image [image create photo -data [summaryTable::iconData]]]
     pack $label -pady 1 -side left
-    new dropSite -path $label -formats DATACELLS -command "createCellsViewer summaryTable \$dragSite::data(DATACELLS) 1 $static"
+    new dropSite -path $label -formats DATACELLS\
+        -command "createCellsViewer summaryTable \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "summary table\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::summaryTable}
 
     set label [label $frame.freeText -image [image create photo -data [freeText::iconData]]]
     pack $label -pady 1 -side left
-    new dropSite -path $label -formats DATACELLS -command "createCellsViewer freeText \$dragSite::data(DATACELLS) 1 $static"
+    new dropSite -path $label -formats DATACELLS\
+        -command "createCellsViewer freeText \$dragSite::data(DATACELLS) 1 $global::static"
     new widgetTip -path $label -text "free text\ndrag'n'drop site"
     set drag [new dragSite -path $label]
     dragSite::provide $drag VIEWER {dragEcho ::freeText}
@@ -159,19 +154,17 @@ if {$::officialBLT} {
 }
 
 proc inquirePollTime {} {
-    global pollTimes pollTime
-
     set dialog\
         [new dialogBox . -buttons oc -default o -title {moodss: Poll Time} -die 0 -x [winfo pointerx .] -y [winfo pointery .]]
     set frame [frame $widget::($dialog,path).frame]
-    set minimum [lindex $pollTimes 0]
+    set minimum [lindex $global::pollTimes 0]
     set message [message $frame.message\
         -width [winfo screenwidth .] -font $font::(mediumNormal) -justify center\
-        -text "Please enter new poll time\n(greater than $minimum):"\
+        -text "Enter new poll time (greater than $minimum):"\
     ]
     pack $message
-    set entry [new spinEntry $frame -width 4 -list $pollTimes -side right]
-    spinEntry::set $entry $pollTime
+    set entry [new spinEntry $frame -width 4 -list $global::pollTimes -side right]
+    spinEntry::set $entry $global::pollTime
     pack $widget::($entry,path) -anchor e -side left -expand 1 -padx 2       ;# evenly pack entry and label together near the center
     pack [label $frame.label -text seconds] -anchor w -side right -expand 1 -padx 2
     dialogBox::display $dialog $frame
@@ -179,10 +172,10 @@ proc inquirePollTime {} {
         set time \[spinEntry::get $entry\]
         if {\$time<$minimum} {                                                                    ;# check against minimum poll time
             bell
-            $message configure -text {Please enter new poll time\n(must be greater than $minimum):}
+            $message configure -text {Enter new poll time\n(must be greater than $minimum):}
         } else {                                                                                                ;# new time is valid
-            if {\$time!=\$pollTime} {                                             ;# but check that it actually differs from current
-                set pollTime \$time
+            if {\$time!=\$global::pollTime} {                                     ;# but check that it actually differs from current
+                set global::pollTime \$time
                 viewer::updateInterval \$time
                 updateTitle
                 refresh                                      ;# update immediately in case poll time was set to a much greater value
