@@ -146,7 +146,7 @@ rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jf
 for installation. It requires the tcl, tk, blt and tktable rpms (see INSTALL
 file for more information). Unless you want to work on the moodss source
 code, you can skip the rest of this section.
-<P>For the current version (6.4), the following packages must be installed
+<P>For the current version (6.5), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -282,9 +282,8 @@ data views (such as pie slices, curves, ...) can be added or removed from
 existing viewers, ... These functions are all implemented using the drag
 and drop functionality described below.
 <P>Graphical viewers available at this time are BLT graph viewers (such
-as can be seen below), side-by-side bars charts, overlapped bars charts
-(only available when the BLT version 2.4 library is used), stacked bars
-charts, 2D pie charts and 3D pie charts*.
+as can be seen below), side-by-side bars charts, overlapped bars charts,
+stacked bars charts, 2D pie charts and 3D pie charts*.
 <P>*<I>note: if you know of any other nice viewers (like 3D graphs) that
 work with Tcl, please let me know so I can integrate them. Many thanks
 in advance...</I>
