@@ -5,8 +5,6 @@ exec wish "$0" "$@"
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set applicationVersion 6.4
-
 proc recordRCSId {variableName empty operation} {
     foreach {header file version} $::rcsId break
     regsub {,v$} $file {} file
@@ -14,12 +12,13 @@ proc recordRCSId {variableName empty operation} {
 }
 trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
 
-set rcsId {$Id: moodss.tcl,v 1.149 1999/02/26 21:28:11 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.158 1999/03/23 22:04:21 jfontain Exp $}
 
 
 source utility.tcl
 startGatheringPackageDirectories
 
+source global.tcl
 source getopt.tcl
 
 proc printUsage {exitCode} {
@@ -52,7 +51,7 @@ foreach {short long} {-f --file -h --help -p --poll-time -r --read-only -S --sta
 }
 
 if {[info exists arguments(--version)]} {
-    puts "moodss (a Modular Object Oriented Dynamic SpreadSheet) version $applicationVersion"
+    puts "moodss (a Modular Object Oriented Dynamic SpreadSheet) version $global::applicationVersion"
     exit
 }
 if {
@@ -113,14 +112,13 @@ if {[catch {package require Tktable 2}]} {
 if {[catch {package require BLT}]} {                                                         ;# in case BLT package is not installed
     switch $tcl_platform(platform) {
         unix {
-            load ./libBLT.so.2.4g
+            load ./libBLT.so.2.4h
         }
         windows {
-            load ./blt80.dll                                                  ;# so far, only unofficial 8.0 is supported on Windows
+            load ./blt24.dll
         }
     }
 }
-set officialBLT [expr {$blt_version!=8.0}]                                               ;# remember which BLT version is being used
 
 wm protocol . WM_DELETE_WINDOW exit      ;# so that closing from window manager works when hung initializing a remote capable module
 wm command . [concat $argv0 $argv]                                   ;# for proper window manager (windowmaker for example) behavior
@@ -165,16 +163,16 @@ source drag.tcl
 source drop.tcl
 
 set readOnly [info exists arguments(-r)]
-set static [info exists arguments(-S)]
+set global::static [info exists arguments(-S)]
 
 set scroll [new scroll canvas .]
-set canvas $composite::($scroll,scrolled,path)
+set global::canvas $composite::($scroll,scrolled,path)
 set width [winfo screenwidth .]
 set height [winfo screenheight .]
-$canvas configure -background white -width $width -height $height -scrollregion [list 0 0 $width $height] -highlightthickness 0\
-    -takefocus 0
+$global::canvas configure -background white -width $width -height $height -scrollregion [list 0 0 $width $height]\
+    -highlightthickness 0 -takefocus 0
 
-set windowManager [new canvasWindowManager $canvas]
+set global::windowManager [new canvasWindowManager $global::canvas]
 
 if {[info exists ::geometry]} {                                                               ;# command line geometry was specified
     wm geometry . $::geometry
@@ -186,9 +184,11 @@ if {[info exists ::geometry]} {
 }
 
 wm iconname . "moodss $modules::(all)"                                                            ;# give the icon a meaningful name
-image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
-wm iconwindow . [toplevel .icon]
-pack [label .icon.image -image applicationIcon]
+if {[string compare $tcl_platform(platform) unix]==0} {
+    image create photo applicationIcon -data [dataGraph::iconData]                            ;# use data graph icon for application
+    wm iconwindow . [toplevel .icon]
+    pack [label .icon.image -image applicationIcon]
+}
 
 if {!$readOnly} {
     pack [createDragAndDropZone .] -fill x
@@ -212,7 +212,7 @@ if {[info exists arguments(-p)]} {
 }
 
 updateTitle                                                                              ;# now that modules and poll time are known
-createMenuWidget . $readOnly [llength $pollTimes]
+createMenuWidget . $readOnly [llength $global::pollTimes]
 
 source keyslink.tcl
 source dialog.tcl
@@ -225,9 +225,7 @@ source html.tcl                                            ;# must be sourced af
 source help.tcl
 
 proc createCellsViewer {class cells draggable static {pollTime {}}} {
-    global canvas
-
-    set viewer [new $class $canvas -draggable $draggable]
+    set viewer [new $class $global::canvas -draggable $draggable]
     if {[string length $pollTime]>0} {
         composite::configure $viewer -interval $pollTime
     }
@@ -237,18 +235,16 @@ proc createCellsViewer {class cells draggable static {pollTime {}}} {
 }
 
 proc manageViewer {viewer destroyable args} {                         ;# arguments are window manager configuration switched options
-    global windowManager
-
     set path $widget::($viewer,path)
-    canvasWindowManager::manage $windowManager $path
-    eval canvasWindowManager::configure $windowManager $path $args
+    canvasWindowManager::manage $global::windowManager $path
+    eval canvasWindowManager::configure $global::windowManager $path $args
     if {$destroyable} {
-        composite::configure $viewer -deletecommand "canvasWindowManager::unmanage $windowManager $path"
+        composite::configure $viewer -deletecommand "canvasWindowManager::unmanage $global::windowManager $path"
     }
 }
 
 proc save {ask} {                               ;# save current configuration in user defined file or currently defined storage file
-    global saveFile messenger
+    global saveFile
 
     if {$ask||([string length $saveFile]==0)} {
         set file [tk_getSaveFile\
@@ -257,27 +253,27 @@ proc save {ask} {                               ;# save current configuration in
         if {[string length $file]==0} return                                                                 ;# user canceled saving
         set saveFile $file
     }
-    lifoLabel::flash $messenger "saving in $saveFile..."                ;# flash instead of pushing as that goes too fast to be seen
+    lifoLabel::flash $global::messenger "saving in $saveFile..."        ;# flash instead of pushing as that goes too fast to be seen
     set record [new record -file $saveFile]
     record::write $record
     delete $record
 }
 
 proc refresh {} {
-    global updateEvent messenger pollTime
+    static updateEvent
 
     catch {after cancel $updateEvent}                                                             ;# eventually cancel current event
 
     if {[llength $modules::(synchronous)]==0} return                                                                ;# nothing to do
 
     # we do not know when data will actually be updated
-    lifoLabel::push $messenger "launching $modules::(synchronous,string) data update..."
+    lifoLabel::push $global::messenger "launching $modules::(synchronous,string) data update..."
     update idletasks
     foreach module $modules::(synchronous) {
         ${module}::update                                                                   ;# ask module to update its dynamic data
     }
-    lifoLabel::pop $messenger
-    set updateEvent [after [expr {1000*$pollTime}] refresh]                                               ;# convert to milliseconds
+    lifoLabel::pop $global::messenger
+    set updateEvent [after [expr {1000*$global::pollTime}] refresh]                                       ;# convert to milliseconds
 }
 
 set draggable [expr {!$readOnly}]
@@ -293,18 +289,18 @@ foreach module $modules::(all) {
     foreach members $viewMembers {
         if {[llength $members]>0} {                                                                                  ;# it is a view
             array set view $members
-            set table [new dataTable $canvas -data ${module}::data -view ::view -draggable $draggable]
+            set table [new dataTable $global::canvas -data ${module}::data -view ::view -draggable $draggable]
             unset view
         } else {                                                                                     ;# use single default data view
-            set table [new dataTable $canvas -data ${module}::data -draggable $draggable]
+            set table [new dataTable $global::canvas -data ${module}::data -draggable $draggable]
         }
         if {[info exists initializer]&&([lsearch -exact $modules::(initialized) $module]>=0)} {  ;# setup initialized modules tables
             eval composite::configure $table [record::tableOptions $initializer $module $index]
             # use stored window manager initialization data for table
             foreach {x y width height level} [record::tableWindowManagerData $initializer $module $index] {}
-            manageViewer $table 0 -static $static -setx $x -sety $y -setwidth $width -setheight $height -level $level
+            manageViewer $table 0 -static $global::static -setx $x -sety $y -setwidth $width -setheight $height -level $level
         } else {
-            manageViewer $table 0 -static $static -setx $x -sety $y
+            manageViewer $table 0 -static $global::static -setx $x -sety $y
         }
         set x [expr {$x+$configuration::(xWindowManagerInitialOffset)}]                   ;# offset tables to achieve a nicer layout
         set y [expr {$y+$configuration::(yWindowManagerInitialOffset)}]
@@ -316,14 +312,14 @@ refresh
 
 if {[info exists initializer]} {                  ;# stored configuration, now that modules data is initialized, create some viewers
     foreach {class cells x y width height level switchedOptions} [record::viewersData $initializer] {
-        set viewer [eval new $class $canvas $switchedOptions -draggable $draggable]
+        set viewer [eval new $class $global::canvas $switchedOptions -draggable $draggable]
         foreach list [composite::configure $viewer] {
             if {[string compare [lindex $list 0] -interval]==0} {                                 ;# viewer supports interval option
-                composite::configure $viewer -interval $pollTime                                          ;# so use current interval
+                composite::configure $viewer -interval $global::pollTime                                  ;# so use current interval
                 break                                                                                                        ;# done
             }
         }
         viewer::view $viewer $cells
-        manageViewer $viewer 1 -static $static -setx $x -sety $y -setwidth $width -setheight $height -level $level
+        manageViewer $viewer 1 -static $global::static -setx $x -sety $y -setwidth $width -setheight $height -level $level
     }
 }
