@@ -1,13 +1,13 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: ps.tcl,v 1.33 1999/01/04 23:17:26 jfontain Exp $}
+set rcsId {$Id: ps.tcl,v 1.34 1999/02/26 21:26:57 jfontain Exp $}
 
 
 # System dependent process data access procedures. Only Linux is supported at this time (who needs another OS?).
 # Corresponding pkgIndex.tcl file content: package ifneeded ps 1.4 "source [file join $dir ps.tcl]"
 
-package provide ps 1.5
+package provide ps 1.6
 package require network 1.2
 
 namespace eval ps {
@@ -64,6 +64,8 @@ $ moodss ps --remote foo.bar.com
 
         if {[info exists remote]} {
             set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /etc/passwd"]
+            fileevent $file readable {set ::ps::remote(busy) 0}
+            vwait ::ps::remote(busy)
         } else {
             set file [open /etc/passwd]
         }
@@ -108,20 +110,19 @@ $ moodss ps --remote foo.bar.com
 
     proc update {} {
         variable remote
-        variable data
 
-        if {[info exists remote]} {
+        if {[info exists remote]&&!$remote(busy)} {
             remoteUpdate
         } else {
             localUpdate
         }
-        incr data(updates)
     }
 
     # gather processes status information (based on the proc man page information and fs/proc/array.c kernel source)
     proc localUpdate {} {
         variable uid                                                                                     ;# pid to uid mapping cache
         variable cmdline                                                                                ;# pid to command line cache
+        variable data
 
         set currentDirectory [pwd]
         cd /proc                                                                                         ;# change to data directory
@@ -179,19 +180,17 @@ $ moodss ps --remote foo.bar.com
         }
 
         cd $currentDirectory
-
         cleanupProcessesData current                                                          ;# clean up disappeared processes data
+        incr data(updates)
     }
 
     proc remoteUpdate {} {                                    ;# modeled after localUpdate{}: comments there are not duplicated here
         variable remote
-        variable uid
-        variable cmdline
 
         # gather data at the other end in 1 shot to minimize network delays and remote processor usage, while also minimizing
         # local processing (data returned in array set command compatible list) and ignoring errors (empty data is then returned)
-        array set there [exec /usr/bin/rsh -nl $remote(user) $remote(host) \
-{\
+
+set command {\
 exec 2>/dev/null
 cd /proc
 echo pid {$$}
@@ -202,8 +201,19 @@ for id in $pids; do
     echo $id,status {$(fgrep Uid: $id/status)} $id,cmdline {$(tr "\0" " " < $id/cmdline)} $id,stat {$(cat $id/stat)}
 done
 echo uptime {$(cat uptime)}\
-}\
-        ]
+}
+        set file [open [list | /usr/bin/rsh -nl $remote(user) $remote(host) $command]]
+        fileevent $file readable "ps::remoteUpdated $file"                   ;# do not hang user interface and other modules updates
+    }
+
+    proc remoteUpdated {file} {                               ;# modeled after localUpdate{}: comments there are not duplicated here
+        variable remote
+        variable uid
+        variable cmdline
+        variable data
+
+        array set there [read $file]
+        close $file                                                                ;### errors and timeouts could be caught here ###
 
         # array sample extract:
         # there(pid)         = 2504
@@ -242,6 +252,8 @@ echo uptime {$(cat uptime)}\
         }
 
         cleanupProcessesData current
+        set remote(busy) 0
+        incr data(updates)
     }
 
     proc updateProcessData {pid uptime clock memoryTotal statLine} {
