@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.17 1999/01/11 20:51:11 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.20 1999/03/08 18:18:52 jfontain Exp $}
 
 
 class record {
@@ -29,13 +29,13 @@ class record {
         }
         set file [open $switched::($this,-file) w+]                                                           ;# create or overwrite
 
-        puts $file "version $::applicationVersion"
+        puts $file "version $global::applicationVersion"
         set seconds [clock seconds]
         puts $file "date [clock format $seconds -format %D] time [clock format $seconds -format %T]"
         puts $file "configuration {}"                                                                      ;### when implemented ###
         # main window coordinates are not saved as it would be bad manners to force initial window placement
         puts $file "width [winfo width .] height [winfo height .]"
-        puts $file "pollTime $::pollTime"
+        puts $file "pollTime $global::pollTime"
         puts $file "modules \{"
         foreach module $modules::(all) {
             puts $file "    $module \{"
@@ -44,8 +44,8 @@ class record {
             foreach table $dataTable::(list) {
                 # filter other module tables
                 if {[string compare $module [namespace qualifiers [composite::cget $table -data]]]!=0} continue
-                foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($table,path)] {}
-                set level [canvasWindowManager::getStackLevel $::windowManager $widget::($table,path)]
+                foreach {x y width height} [canvasWindowManager::getGeometry $global::windowManager $widget::($table,path)] {}
+                set level [canvasWindowManager::getStackLevel $global::windowManager $widget::($table,path)]
                 puts $file "            $table \{"
                 puts $file "                x $x y $y width $width height $height level $level"
                 foreach {switch value} [dataTable::initializationConfiguration $table] {
@@ -61,8 +61,8 @@ class record {
         foreach viewer $viewer::(list) {
             puts $file "    $viewer \{"
             puts $file "        class [classof $viewer]"
-            foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($viewer,path)] {}
-            set level [canvasWindowManager::getStackLevel $::windowManager $widget::($viewer,path)]
+            foreach {x y width height} [canvasWindowManager::getGeometry $global::windowManager $widget::($viewer,path)] {}
+            set level [canvasWindowManager::getStackLevel $global::windowManager $widget::($viewer,path)]
             puts $file "        x $x y $y width $width height $height level $level"
             puts $file "        cells {[viewer::cells $viewer]}"
             foreach {switch value} [viewer::initializationConfiguration $viewer] {
