@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: utility.tcl,v 1.9 1999/01/26 20:32:25 jfontain Exp $}
+set rcsId {$Id: utility.tcl,v 1.10 1999/03/06 21:27:07 jfontain Exp $}
 
 proc minimum {a b} {return [expr {$a<$b?$a:$b}]}
 proc maximum {a b} {return [expr {$a>$b?$a:$b}]}
@@ -25,6 +25,14 @@ proc commaSeparatedString {words} {
     return $string
 }
 
+proc static {localName {initialValue {}}} {
+    set global ::[lindex [info level -1] 0]:$localName
+    uplevel upvar #0 $global $localName
+    if {![info exists $global]} {
+        set $global $initialValue
+    }
+}
+
 proc startGatheringPackageDirectories {} {
     catch {rename source _source}
     proc source {file} {
