@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: viewer.tcl,v 1.23 1999/01/29 21:52:03 jfontain Exp $}
+set rcsId {$Id: viewer.tcl,v 1.28 1999/03/07 20:58:36 jfontain Exp $}
 
 class viewer {                                                                             ;# handle viewers related functionalities
     # viewers do not derive from a common interface class but rather support a common set a options through the composite class
@@ -45,7 +45,7 @@ class viewer {
         foreach cell $cells {
             parse $cell array row column type
             if {[lsearch -exact [supportedTypes $this] $type]<0} {
-                lifoLabel::flash $::messenger "cannot display data of type $type"
+                lifoLabel::flash $global::messenger "cannot display data of type $type"
                 bell
                 return {}                                                                                    ;# give up on all cells
             }
@@ -128,10 +128,10 @@ class viewer {
 
     proc mutate {this class} {
         if {[string compare $class [classof $this]]==0} return                       ;# no need to create a viewer of the same class
-        set viewer [eval new $class $::canvas -draggable [composite::cget $this -draggable]]
+        set viewer [eval new $class $global::canvas -draggable [composite::cget $this -draggable]]
         foreach list [composite::configure $viewer] {
             if {[string compare [lindex $list 0] -interval]==0} {                                 ;# viewer supports interval option
-                composite::configure $viewer -interval $::pollTime                                        ;# so use current interval
+                composite::configure $viewer -interval $global::pollTime                                  ;# so use current interval
                 break                                                                                                        ;# done
             }
         }
@@ -148,13 +148,13 @@ class viewer {
             view $viewer $cells
         }
         if {[llength $cells]<$count} {                                                                   ;# warn user when necessary
-            lifoLabel::flash $::messenger {some data cells no longer exist}
+            lifoLabel::flash $global::messenger {some data cells no longer exist}
         }
-        foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($this,path)] {}
-        set level [canvasWindowManager::getStackLevel $::windowManager $widget::($this,path)]
+        foreach {x y width height} [canvasWindowManager::getGeometry $global::windowManager $widget::($this,path)] {}
+        set level [canvasWindowManager::getStackLevel $global::windowManager $widget::($this,path)]
         delete $this                                                                                       ;# delete existing viewer
         # viewer is as destroyable as previously deleted viewer
-        manageViewer $viewer 1 -static $::static -setx $x -sety $y -setwidth $width -setheight $height -level $level
+        manageViewer $viewer 1 -static $global::static -setx $x -sety $y -setwidth $width -setheight $height -level $level
     }
 
 }
